# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
# isort: skip_file
from .....schema_classes import ActorsClass
from .....schema_classes import RoleGroupClass
from .....schema_classes import RolePropertiesClass
from .....schema_classes import RoleUserClass


Actors = ActorsClass
RoleGroup = RoleGroupClass
RoleProperties = RolePropertiesClass
RoleUser = RoleUserClass

# fmt: on
